Module beamlit.models.metrics
=============================

Classes
-------

`Metrics(agents: beamlit.types.Unset | Any = <beamlit.types.Unset object>, functions: beamlit.types.Unset | Any = <beamlit.types.Unset object>, inference_global: beamlit.types.Unset | list[typing.Any] = <beamlit.types.Unset object>, models: beamlit.types.Unset | ForwardRef('MetricsModels') = <beamlit.types.Unset object>, request_total: beamlit.types.Unset | float = <beamlit.types.Unset object>, request_total_per_code: beamlit.types.Unset | ForwardRef('MetricsRequestTotalPerCode') = <beamlit.types.Unset object>, rps: beamlit.types.Unset | float = <beamlit.types.Unset object>, rps_per_code: beamlit.types.Unset | ForwardRef('MetricsRpsPerCode') = <beamlit.types.Unset object>)`
:   Metrics for resources
    
    Attributes:
        agents (Union[Unset, Any]): Metrics for agents
        functions (Union[Unset, Any]): Metrics for functions
        inference_global (Union[Unset, list[Any]]): Historical requests for all resources globally
        models (Union[Unset, MetricsModels]): Metrics for models
        request_total (Union[Unset, float]): Number of requests for all resources globally
        request_total_per_code (Union[Unset, MetricsRequestTotalPerCode]): Number of requests for all resources globally
            per code
        rps (Union[Unset, float]): Number of requests per second for all resources globally
        rps_per_code (Union[Unset, MetricsRpsPerCode]): Number of requests per second for all resources globally per
            code
    
    Method generated by attrs for class Metrics.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `agents`
    :

    `functions`
    :

    `inference_global`
    :

    `models`
    :

    `request_total`
    :

    `request_total_per_code`
    :

    `rps`
    :

    `rps_per_code`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :